---
name: Bug report
about: Create a report to help us improve
title: "[KiPart BUG]"
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - OS [type & version]
 - Python version
 - KiPart version [e.g. 0.1.22]

**Additional context**
Add any other context about the problem here.
